% binchi_pdf.m - evaluates a Compound Binomial Chi Probability Density.
%   See "The Compounding of the Binomial and Generalized Beta Distributions",   
%   T. Gerstenkorn, Prob. and Statistical Inference, p.87, 1982. 
%
%   NORMALIZATION PUTS A COMPLICATED UPPER LIMIT ON 'c'.
%
%  Created by Jim Huntley,  06/08/11
%

function [pdf] = binchi_pdf(nh,nn,b,c,md2)

for jn = 1:size(nh,2) 
    sumk = 0;
    n = nh(jn);
    gammd2 = gamma(md2);
    bcnndx = binomial_coef(nn,n);
    for jk = 1:nn-n
        k = jk - 1;
        sumk = sumk + binomial_coef(nn-n,k) * (-1)^k * (b*c^2)^((n+k)/2) * ...
               gamma(md2+(n+k)/2);
    end
    pdf(jn) = sumk * bcnndx / gammd2;
end

return
