% binexp_pdf.m - evaluates a Compound Binomial Exponential Probability Density.
%   See "The Compounding of the Binomial and Generalized Beta Distributions",   
%   T. Gerstenkorn, Prob. and Statistical Inference, p.87, 1982. 
%
%   NORMALIZATION PUTS A COMPLICATED UPPER LIMIT ON 'c'.
%
%  Created by Jim Huntley,  06/13/11
%

function [pdf] = binexp_pdf(nh,nn,b,c)

for jn = 1:size(nh,2) 
    sumk = 0;
    n = nh(jn);
    bcnndx = binomial_coef(nn,n);
    for jk = 1:nn-n
        k = jk - 1;
        sumk = sumk + binomial_coef(nn-n,k) * (-1)^k * (b*c)^(n+k) * ...
               gamma(1+n+k);
    end
    pdf(jn) = sumk * bcnndx;
end

return