% binmax_pdf.m - evaluates a Compound Binomial Maxwell Probability Density.
%   See "The Compounding of the Binomial and Generalized Beta Distributions",   
%   T. Gerstenkorn, Prob. and Statistical Inference, p.87, 1982. 
%
%   NORMALIZATION PUTS A COMPLICATED UPPER LIMIT ON 'c'.
%
%  Created by Jim Huntley,  06/13/11
%

function [pdf] = binmax_pdf(nh,nn,b,c)

for jn = 1:size(nh,2) 
    sumk = 0;
    n = nh(jn);
    gam3d2 = gamma(3/2);
    bcnndx = binomial_coef(nn,n);
    for jk = 1:nn-n
        k = jk - 1;
        sumk = sumk + binomial_coef(nn-n,k) * (-1)^k * (b*c^2)^((n+k)/2) * ...
               gamma((3+n+k)/2);
    end
    pdf(jn) = sumk * bcnndx / gam3d2;
end

return