% czeled_pdf.m - evaluates a Czeledin Probability Density.
%   See "The Czeledin Distribution Function", M. Knecht and S. Kuttel, Converium Ltd.
%
%  Created by Jim Huntley,  08/10/06
%
%

function [y] = czeled_pdf(x, mu, sigma, kappa)

sigma02 = log(1 + sigma^2/mu^2);
sigma0 = sqrt(sigma02);
mu0 = log(mu/kappa) - 0.5*sigma02;
mu02 = mu0^2;
alpha = exp(-0.5*mu02/sigma02) / (sqrt(2*pi)*sigma0*gaus_cdf(mu0/sigma0,0,1));
if(x < kappa)
    L = logn_pdf(x,mu,sigma);
    y = L;
else
    P = pareto_pdf(x,alpha,kappa);
    L = logn_pdf(kappa,mu,sigma);
    y = L + (1-L)*P;
end

return