% powertail_pdf.m - evaluates a Power tail Probability Density.
%   See "Performance of Class-Based Queues with Self-Similar Traffic"
%   J. Orellana et al., University College London.
%
%  Created by Jim Huntley,  07/24/06
%
%

function [y] = powertail_pdf(x, theta, gam, N);

M = (1-theta) / (1 - gam*theta);
G = (1-theta) / (1 - theta^N);
ratio = theta/gam;
sum = 0;

for jn = 1:N
    sum = sum + ratio^(jn-1) * exp(-M*x/gam^(jn-1));
end
y = M * G * sum;

return