% ptad_cdf.m - evaluates a Power Tail Cumulative Distribution.
%   See "Performance of Class-Based Queues with Self-Similar Traffic"
%   J. Orellana et al., University College London.
%
%  Created by Jim Huntley,  07/24/06
%

function [cdf] = ptad_cdf(x, theta, gam, N)

M = (1-theta) / (1 - gam*theta);
G = (1-theta) / (1 - theta^N);
sum1 = 0;

for jn = 1:N
    sum1 = sum1 + theta^(jn-1) * exp(-M*x/gam^(jn-1));
end
cdf = 1 - G * sum1;

return